Tenma Power Supplies Control Library
------------------------------------

This repository contains ``tenmactl`` a simple library to control Tenma 72-XXXX
power supplies using serial communications. Check the ``examples`` folder for
usage examples.
